aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2018-11-25 08:51:51 +0200
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2018-11-25 08:51:51 +0200
commitc02a988bda6724dcbd1d689be2010ce55de59368 (patch)
treef0e9bcc67c0db00fe04517b6bccbacb63a5214ac /Software/Visual_Studio
parent88a0169f624c77b77b21a871ace9e51a9245807d (diff)
downloadTango-c02a988bda6724dcbd1d689be2010ce55de59368.tar.gz
Tango-c02a988bda6724dcbd1d689be2010ce55de59368.zip
Storage Module!
Diffstat (limited to 'Software/Visual_Studio')
-rw-r--r--Software/Visual_Studio/Notes/Tango.Notes/PPC/Virtual Flash Drive.txt5
-rw-r--r--Software/Visual_Studio/Notes/Tango.Notes/Tango.Notes.csproj3
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/App.xaml11
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Images/storage-module.pngbin0 -> 1377 bytes
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/AssemblyInfo.cs20
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.Designer.cs62
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.resx117
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.Designer.cs30
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.settings7
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/StorageModule.cs84
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Tango.PPC.Storage.csproj130
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItem.cs24
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItemView.xaml24
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItemView.xaml.cs (renamed from Software/Visual_Studio/PPC/Tango.PPC.UI/Views/StorageView.xaml.cs)8
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewContracts/IMainView.cs15
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewModelLocator.cs32
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewModels/MainViewVM.cs (renamed from Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/StorageViewVM.cs)50
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml18
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml.cs37
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs25
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/TaskBarItem.cs13
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/DefaultStorageProvider.cs48
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/IStorageProvider.cs20
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Tango.PPC.Common.csproj7
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Converters/ItemBaseConverter.cs (renamed from Software/Visual_Studio/PPC/Tango.PPC.UI/Converters/NotificationItemConverter.cs)4
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Notifications/DefaultNotificationProvider.cs36
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj16
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs9
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Views/LayoutView.xaml11
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Views/MainView.xaml30
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/Views/StorageView.xaml33
-rw-r--r--Software/Visual_Studio/Tango.BL/EntitiesExtensions/LiquidTypesRml.cs4
-rw-r--r--Software/Visual_Studio/Tango.Explorer/ExplorerControl.cs2
-rw-r--r--Software/Visual_Studio/Tango.sln55
36 files changed, 893 insertions, 101 deletions
diff --git a/Software/Visual_Studio/Notes/Tango.Notes/PPC/Virtual Flash Drive.txt b/Software/Visual_Studio/Notes/Tango.Notes/PPC/Virtual Flash Drive.txt
new file mode 100644
index 000000000..2f92bf6f0
--- /dev/null
+++ b/Software/Visual_Studio/Notes/Tango.Notes/PPC/Virtual Flash Drive.txt
@@ -0,0 +1,5 @@
+#Create Virtual Removable Drive
+imdisk -a -s 10M -m R: -o rem -p "/fs:ntfs /q /y"
+
+#Remove Virtual Drive
+imdisk -D -m R: \ No newline at end of file
diff --git a/Software/Visual_Studio/Notes/Tango.Notes/Tango.Notes.csproj b/Software/Visual_Studio/Notes/Tango.Notes/Tango.Notes.csproj
index 66f30b1a4..e21ec34aa 100644
--- a/Software/Visual_Studio/Notes/Tango.Notes/Tango.Notes.csproj
+++ b/Software/Visual_Studio/Notes/Tango.Notes/Tango.Notes.csproj
@@ -45,6 +45,7 @@
<ItemGroup>
<Content Include="Azure\SQL Database.txt" />
<Content Include="PPC\Remote Debugging.txt" />
+ <Content Include="PPC\Virtual Flash Drive.txt" />
<Content Include="PPC\Windows 10 LTSB.txt" />
<Content Include="PPC\Touch.txt" />
<Content Include="VMWare\License Key.txt" />
@@ -52,7 +53,7 @@
<Import Project="$(MSBuildToolsPath)\Microsoft.CSharp.targets" />
<ProjectExtensions>
<VisualStudio>
- <UserProperties BuildVersion_StartDate="2000/1/1" BuildVersion_UseGlobalSettings="False" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" />
+ <UserProperties BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UseGlobalSettings="False" BuildVersion_StartDate="2000/1/1" />
</VisualStudio>
</ProjectExtensions>
</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/Properties/AssemblyInfo.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/Properties/AssemblyInfo.cs
index 657d58fa3..095f10d3b 100644
--- a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/Properties/AssemblyInfo.cs
@@ -7,7 +7,7 @@ using System.Windows;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("Tango Panel PC Jobs Module")]
+[assembly: AssemblyTitle("Tango PPC Jobs Module")]
[assembly: AssemblyVersion("2.0.7.1119")]
[assembly:ThemeInfo(
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/Properties/AssemblyInfo.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/Properties/AssemblyInfo.cs
index 8e6777b64..d07b99ec8 100644
--- a/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/Properties/AssemblyInfo.cs
@@ -7,7 +7,7 @@ using System.Windows;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("Tango Module")]
+[assembly: AssemblyTitle("Tango PPC Settings Module")]
[assembly: AssemblyVersion("2.0.4.1119")]
[assembly: ThemeInfo(
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/App.xaml b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/App.xaml
new file mode 100644
index 000000000..3a30cbc37
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/App.xaml
@@ -0,0 +1,11 @@
+<Application x:Class="Tango.PPC.Storage.App"
+ xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
+ xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml">
+ <Application.Resources>
+ <ResourceDictionary>
+ <ResourceDictionary.MergedDictionaries>
+ <ResourceDictionary Source="pack://application:,,,/Tango.PPC.Common;component/Resources/Merged.xaml" />
+ </ResourceDictionary.MergedDictionaries>
+ </ResourceDictionary>
+ </Application.Resources>
+</Application> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Images/storage-module.png b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Images/storage-module.png
new file mode 100644
index 000000000..252e42e38
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Images/storage-module.png
Binary files differ
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/AssemblyInfo.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/AssemblyInfo.cs
new file mode 100644
index 000000000..201341ef7
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/AssemblyInfo.cs
@@ -0,0 +1,20 @@
+using System.Reflection;
+using System.Resources;
+using System.Runtime.CompilerServices;
+using System.Runtime.InteropServices;
+using System.Windows;
+
+// General Information about an assembly is controlled through the following
+// set of attributes. Change these attribute values to modify the information
+// associated with an assembly.
+[assembly: AssemblyTitle("Tango PPC Storage Module")]
+[assembly: AssemblyVersion("2.0.2.1119")]
+
+[assembly: ThemeInfo(
+ ResourceDictionaryLocation.None, //where theme specific resource dictionaries are located
+ //(used if a resource is not found in the page,
+ // or application resource dictionaries)
+ ResourceDictionaryLocation.SourceAssembly //where the generic resource dictionary is located
+ //(used if a resource is not found in the page,
+ // app, or any theme specific resource dictionaries)
+)]
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.Designer.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.Designer.cs
new file mode 100644
index 000000000..8d882d6ad
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.Designer.cs
@@ -0,0 +1,62 @@
+//------------------------------------------------------------------------------
+// <auto-generated>
+// This code was generated by a tool.
+// Runtime Version:4.0.30319.42000
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated.
+// </auto-generated>
+//------------------------------------------------------------------------------
+
+namespace Tango.PPC.Storage.Properties {
+
+
+ /// <summary>
+ /// A strongly-typed resource class, for looking up localized strings, etc.
+ /// </summary>
+ // This class was auto-generated by the StronglyTypedResourceBuilder
+ // class via a tool like ResGen or Visual Studio.
+ // To add or remove a member, edit your .ResX file then rerun ResGen
+ // with the /str option, or rebuild your VS project.
+ [global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "4.0.0.0")]
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
+ [global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
+ internal class Resources {
+
+ private static global::System.Resources.ResourceManager resourceMan;
+
+ private static global::System.Globalization.CultureInfo resourceCulture;
+
+ [global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
+ internal Resources() {
+ }
+
+ /// <summary>
+ /// Returns the cached ResourceManager instance used by this class.
+ /// </summary>
+ [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
+ internal static global::System.Resources.ResourceManager ResourceManager {
+ get {
+ if ((resourceMan == null)) {
+ global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("Tango.PPC.Storage.Properties.Resources", typeof(Resources).Assembly);
+ resourceMan = temp;
+ }
+ return resourceMan;
+ }
+ }
+
+ /// <summary>
+ /// Overrides the current thread's CurrentUICulture property for all
+ /// resource lookups using this strongly typed resource class.
+ /// </summary>
+ [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
+ internal static global::System.Globalization.CultureInfo Culture {
+ get {
+ return resourceCulture;
+ }
+ set {
+ resourceCulture = value;
+ }
+ }
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.resx b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.resx
new file mode 100644
index 000000000..af7dbebba
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Resources.resx
@@ -0,0 +1,117 @@
+<?xml version="1.0" encoding="utf-8"?>
+<root>
+ <!--
+ Microsoft ResX Schema
+
+ Version 2.0
+
+ The primary goals of this format is to allow a simple XML format
+ that is mostly human readable. The generation and parsing of the
+ various data types are done through the TypeConverter classes
+ associated with the data types.
+
+ Example:
+
+ ... ado.net/XML headers & schema ...
+ <resheader name="resmimetype">text/microsoft-resx</resheader>
+ <resheader name="version">2.0</resheader>
+ <resheader name="reader">System.Resources.ResXResourceReader, System.Windows.Forms, ...</resheader>
+ <resheader name="writer">System.Resources.ResXResourceWriter, System.Windows.Forms, ...</resheader>
+ <data name="Name1"><value>this is my long string</value><comment>this is a comment</comment></data>
+ <data name="Color1" type="System.Drawing.Color, System.Drawing">Blue</data>
+ <data name="Bitmap1" mimetype="application/x-microsoft.net.object.binary.base64">
+ <value>[base64 mime encoded serialized .NET Framework object]</value>
+ </data>
+ <data name="Icon1" type="System.Drawing.Icon, System.Drawing" mimetype="application/x-microsoft.net.object.bytearray.base64">
+ <value>[base64 mime encoded string representing a byte array form of the .NET Framework object]</value>
+ <comment>This is a comment</comment>
+ </data>
+
+ There are any number of "resheader" rows that contain simple
+ name/value pairs.
+
+ Each data row contains a name, and value. The row also contains a
+ type or mimetype. Type corresponds to a .NET class that support
+ text/value conversion through the TypeConverter architecture.
+ Classes that don't support this are serialized and stored with the
+ mimetype set.
+
+ The mimetype is used for serialized objects, and tells the
+ ResXResourceReader how to depersist the object. This is currently not
+ extensible. For a given mimetype the value must be set accordingly:
+
+ Note - application/x-microsoft.net.object.binary.base64 is the format
+ that the ResXResourceWriter will generate, however the reader can
+ read any of the formats listed below.
+
+ mimetype: application/x-microsoft.net.object.binary.base64
+ value : The object must be serialized with
+ : System.Serialization.Formatters.Binary.BinaryFormatter
+ : and then encoded with base64 encoding.
+
+ mimetype: application/x-microsoft.net.object.soap.base64
+ value : The object must be serialized with
+ : System.Runtime.Serialization.Formatters.Soap.SoapFormatter
+ : and then encoded with base64 encoding.
+
+ mimetype: application/x-microsoft.net.object.bytearray.base64
+ value : The object must be serialized into a byte array
+ : using a System.ComponentModel.TypeConverter
+ : and then encoded with base64 encoding.
+ -->
+ <xsd:schema id="root" xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
+ <xsd:element name="root" msdata:IsDataSet="true">
+ <xsd:complexType>
+ <xsd:choice maxOccurs="unbounded">
+ <xsd:element name="metadata">
+ <xsd:complexType>
+ <xsd:sequence>
+ <xsd:element name="value" type="xsd:string" minOccurs="0" />
+ </xsd:sequence>
+ <xsd:attribute name="name" type="xsd:string" />
+ <xsd:attribute name="type" type="xsd:string" />
+ <xsd:attribute name="mimetype" type="xsd:string" />
+ </xsd:complexType>
+ </xsd:element>
+ <xsd:element name="assembly">
+ <xsd:complexType>
+ <xsd:attribute name="alias" type="xsd:string" />
+ <xsd:attribute name="name" type="xsd:string" />
+ </xsd:complexType>
+ </xsd:element>
+ <xsd:element name="data">
+ <xsd:complexType>
+ <xsd:sequence>
+ <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1" />
+ <xsd:element name="comment" type="xsd:string" minOccurs="0" msdata:Ordinal="2" />
+ </xsd:sequence>
+ <xsd:attribute name="name" type="xsd:string" msdata:Ordinal="1" />
+ <xsd:attribute name="type" type="xsd:string" msdata:Ordinal="3" />
+ <xsd:attribute name="mimetype" type="xsd:string" msdata:Ordinal="4" />
+ </xsd:complexType>
+ </xsd:element>
+ <xsd:element name="resheader">
+ <xsd:complexType>
+ <xsd:sequence>
+ <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1" />
+ </xsd:sequence>
+ <xsd:attribute name="name" type="xsd:string" use="required" />
+ </xsd:complexType>
+ </xsd:element>
+ </xsd:choice>
+ </xsd:complexType>
+ </xsd:element>
+ </xsd:schema>
+ <resheader name="resmimetype">
+ <value>text/microsoft-resx</value>
+ </resheader>
+ <resheader name="version">
+ <value>2.0</value>
+ </resheader>
+ <resheader name="reader">
+ <value>System.Resources.ResXResourceReader, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
+ </resheader>
+ <resheader name="writer">
+ <value>System.Resources.ResXResourceWriter, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
+ </resheader>
+</root> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.Designer.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.Designer.cs
new file mode 100644
index 000000000..8e95a1b27
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.Designer.cs
@@ -0,0 +1,30 @@
+//------------------------------------------------------------------------------
+// <auto-generated>
+// This code was generated by a tool.
+// Runtime Version:4.0.30319.42000
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated.
+// </auto-generated>
+//------------------------------------------------------------------------------
+
+namespace Tango.PPC.Storage.Properties
+{
+
+
+ [global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
+ [global::System.CodeDom.Compiler.GeneratedCodeAttribute("Microsoft.VisualStudio.Editors.SettingsDesigner.SettingsSingleFileGenerator", "11.0.0.0")]
+ internal sealed partial class Settings : global::System.Configuration.ApplicationSettingsBase
+ {
+
+ private static Settings defaultInstance = ((Settings)(global::System.Configuration.ApplicationSettingsBase.Synchronized(new Settings())));
+
+ public static Settings Default
+ {
+ get
+ {
+ return defaultInstance;
+ }
+ }
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.settings b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.settings
new file mode 100644
index 000000000..033d7a5e9
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Properties/Settings.settings
@@ -0,0 +1,7 @@
+<?xml version='1.0' encoding='utf-8'?>
+<SettingsFile xmlns="uri:settings" CurrentProfile="(Default)">
+ <Profiles>
+ <Profile Name="(Default)" />
+ </Profiles>
+ <Settings />
+</SettingsFile> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/StorageModule.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/StorageModule.cs
new file mode 100644
index 000000000..a589e35bd
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/StorageModule.cs
@@ -0,0 +1,84 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using System.Windows.Media.Imaging;
+using Tango.BL.Enumerations;
+using Tango.PPC.Common;
+using Tango.PPC.Storage.Views;
+using Tango.SharedUI.Helpers;
+
+namespace Tango.PPC.Storage
+{
+ /// <summary>
+ /// Represents a PPC <see cref="StorageModule"/>.
+ /// </summary>
+ /// <seealso cref="Tango.PPC.Common.PPCModuleBase" />
+ [PPCModule(3)]
+ public class StorageModule : PPCModuleBase
+ {
+ /// <summary>
+ /// Gets the module name.
+ /// </summary>
+ public override string Name
+ {
+ get
+ {
+ return "Storage";
+ }
+ }
+
+ /// <summary>
+ /// Gets the module description.
+ /// </summary>
+ public override string Description
+ {
+ get
+ {
+ return "Tango PPC Removable Drive Storage Module.";
+ }
+ }
+
+ /// <summary>
+ /// Gets the module cover image.
+ /// </summary>
+ public override BitmapSource Image
+ {
+ get
+ {
+ return ResourceHelper.GetImageFromResources("Images/storage-module.png");
+ }
+ }
+
+ /// <summary>
+ /// Gets the module entry point view type.
+ /// </summary>
+ public override Type MainViewType
+ {
+ get
+ {
+ return typeof(MainView);
+ }
+ }
+
+ /// <summary>
+ /// Gets the permission required to see and load this module.
+ /// </summary>
+ public override Permissions Permission
+ {
+ get
+ {
+ return Permissions.RunMachineStudio;
+ }
+ }
+
+ /// <summary>
+ /// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
+ /// </summary>
+ public override void Dispose()
+ {
+ //Dispose module here...
+ }
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Tango.PPC.Storage.csproj b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Tango.PPC.Storage.csproj
new file mode 100644
index 000000000..b6a2c885b
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Tango.PPC.Storage.csproj
@@ -0,0 +1,130 @@
+<?xml version="1.0" encoding="utf-8"?>
+<Project ToolsVersion="15.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+ <Import Project="$(MSBuildExtensionsPath)\$(MSBuildToolsVersion)\Microsoft.Common.props" Condition="Exists('$(MSBuildExtensionsPath)\$(MSBuildToolsVersion)\Microsoft.Common.props')" />
+ <PropertyGroup>
+ <Configuration Condition=" '$(Configuration)' == '' ">Debug</Configuration>
+ <Platform Condition=" '$(Platform)' == '' ">AnyCPU</Platform>
+ <ProjectGuid>{04FEBB02-F782-4B96-B47D-F6902AFA43BE}</ProjectGuid>
+ <OutputType>library</OutputType>
+ <RootNamespace>Tango.PPC.Storage</RootNamespace>
+ <AssemblyName>Tango.PPC.Storage</AssemblyName>
+ <TargetFrameworkVersion>v4.6.1</TargetFrameworkVersion>
+ <FileAlignment>512</FileAlignment>
+ <ProjectTypeGuids>{60dc8134-eba5-43b8-bcc9-bb4bc16c2548};{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}</ProjectTypeGuids>
+ <WarningLevel>4</WarningLevel>
+ </PropertyGroup>
+ <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|AnyCPU' ">
+ <DebugSymbols>true</DebugSymbols>
+ <DebugType>full</DebugType>
+ <Optimize>false</Optimize>
+ <OutputPath>..\..\..\Build\PPC\Debug\</OutputPath>
+ <DefineConstants>DEBUG;TRACE</DefineConstants>
+ <ErrorReport>prompt</ErrorReport>
+ <WarningLevel>4</WarningLevel>
+ </PropertyGroup>
+ <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|AnyCPU' ">
+ <DebugType>pdbonly</DebugType>
+ <Optimize>true</Optimize>
+ <OutputPath>..\..\..\Build\PPC\Release\</OutputPath>
+ <DefineConstants>TRACE</DefineConstants>
+ <ErrorReport>prompt</ErrorReport>
+ <WarningLevel>4</WarningLevel>
+ </PropertyGroup>
+ <ItemGroup>
+ <Reference Include="System" />
+ <Reference Include="System.Data" />
+ <Reference Include="System.Xml" />
+ <Reference Include="Microsoft.CSharp" />
+ <Reference Include="System.Core" />
+ <Reference Include="System.Xml.Linq" />
+ <Reference Include="System.Data.DataSetExtensions" />
+ <Reference Include="System.Net.Http" />
+ <Reference Include="System.Xaml">
+ <RequiredTargetFramework>4.0</RequiredTargetFramework>
+ </Reference>
+ <Reference Include="WindowsBase" />
+ <Reference Include="PresentationCore" />
+ <Reference Include="PresentationFramework" />
+ </ItemGroup>
+ <ItemGroup>
+ <Compile Include="..\..\..\Versioning\GlobalVersionInfo.cs">
+ <Link>GlobalVersionInfo.cs</Link>
+ </Compile>
+ <Compile Include="StorageModule.cs" />
+ <Compile Include="Properties\AssemblyInfo.cs">
+ <SubType>Code</SubType>
+ </Compile>
+ <Compile Include="Properties\Resources.Designer.cs">
+ <AutoGen>True</AutoGen>
+ <DesignTime>True</DesignTime>
+ <DependentUpon>Resources.resx</DependentUpon>
+ </Compile>
+ <Compile Include="Properties\Settings.Designer.cs">
+ <AutoGen>True</AutoGen>
+ <DependentUpon>Settings.settings</DependentUpon>
+ <DesignTimeSharedInput>True</DesignTimeSharedInput>
+ </Compile>
+ <Compile Include="TaskBarItems\StorageTaskBarItem.cs" />
+ <Compile Include="TaskBarItems\StorageTaskBarItemView.xaml.cs">
+ <DependentUpon>StorageTaskBarItemView.xaml</DependentUpon>
+ </Compile>
+ <Compile Include="ViewContracts\IMainView.cs" />
+ <Compile Include="ViewModelLocator.cs" />
+ <Compile Include="ViewModels\MainViewVM.cs" />
+ <Compile Include="Views\MainView.xaml.cs">
+ <DependentUpon>MainView.xaml</DependentUpon>
+ </Compile>
+ <EmbeddedResource Include="Properties\Resources.resx">
+ <Generator>ResXFileCodeGenerator</Generator>
+ <LastGenOutput>Resources.Designer.cs</LastGenOutput>
+ </EmbeddedResource>
+ <None Include="Properties\Settings.settings">
+ <Generator>SettingsSingleFileGenerator</Generator>
+ <LastGenOutput>Settings.Designer.cs</LastGenOutput>
+ </None>
+ </ItemGroup>
+ <ItemGroup>
+ <ProjectReference Include="..\..\..\Tango.BL\Tango.BL.csproj">
+ <Project>{f441feee-322a-4943-b566-110e12fd3b72}</Project>
+ <Name>Tango.BL</Name>
+ </ProjectReference>
+ <ProjectReference Include="..\..\..\Tango.Core\Tango.Core.csproj">
+ <Project>{a34ee0f0-649d-41c8-8489-b6f1cc6924ee}</Project>
+ <Name>Tango.Core</Name>
+ </ProjectReference>
+ <ProjectReference Include="..\..\..\Tango.Explorer\Tango.Explorer.csproj">
+ <Project>{4399af76-db52-4cfb-8020-6f85bdb29fd5}</Project>
+ <Name>Tango.Explorer</Name>
+ </ProjectReference>
+ <ProjectReference Include="..\..\..\Tango.SharedUI\Tango.SharedUI.csproj">
+ <Project>{8491d07b-c1f6-4b62-a412-41b9fd2d6538}</Project>
+ <Name>Tango.SharedUI</Name>
+ </ProjectReference>
+ <ProjectReference Include="..\..\..\Tango.Touch\Tango.Touch.csproj">
+ <Project>{fd86424c-6e84-491b-8df9-3d0f5c236a2a}</Project>
+ <Name>Tango.Touch</Name>
+ </ProjectReference>
+ <ProjectReference Include="..\..\Tango.PPC.Common\Tango.PPC.Common.csproj">
+ <Project>{0be74eee-22cb-4dba-b896-793b9e1a3ac0}</Project>
+ <Name>Tango.PPC.Common</Name>
+ </ProjectReference>
+ </ItemGroup>
+ <ItemGroup>
+ <Page Include="App.xaml">
+ <Generator>MSBuild:Compile</Generator>
+ <SubType>Designer</SubType>
+ </Page>
+ <Page Include="TaskBarItems\StorageTaskBarItemView.xaml">
+ <SubType>Designer</SubType>
+ <Generator>MSBuild:Compile</Generator>
+ </Page>
+ <Page Include="Views\MainView.xaml">
+ <Generator>MSBuild:Compile</Generator>
+ <SubType>Designer</SubType>
+ </Page>
+ </ItemGroup>
+ <ItemGroup>
+ <Resource Include="Images\storage-module.png" />
+ </ItemGroup>
+ <Import Project="$(MSBuildToolsPath)\Microsoft.CSharp.targets" />
+</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItem.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItem.cs
new file mode 100644
index 000000000..a77d47713
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItem.cs
@@ -0,0 +1,24 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using Tango.Core.DI;
+using Tango.PPC.Common.Notifications;
+using Tango.PPC.Common.Storage;
+
+namespace Tango.PPC.Storage.TaskBarItems
+{
+ public class StorageTaskBarItem : TaskBarItem
+ {
+ public override Type ViewType => typeof(StorageTaskBarItemView);
+
+ [TangoInject]
+ public IStorageProvider StorageProvider { get; set; }
+
+ public StorageTaskBarItem()
+ {
+ TangoIOC.Default.Inject(this);
+ }
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItemView.xaml b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItemView.xaml
new file mode 100644
index 000000000..dc63949a0
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItemView.xaml
@@ -0,0 +1,24 @@
+<UserControl x:Class="Tango.PPC.Storage.TaskBarItems.StorageTaskBarItemView"
+ xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
+ xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
+ xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
+ xmlns:d="http://schemas.microsoft.com/expression/blend/2008"
+ xmlns:touch="clr-namespace:Tango.Touch.Controls;assembly=Tango.Touch"
+ xmlns:local="clr-namespace:Tango.PPC.Storage.TaskBarItems"
+ mc:Ignorable="d"
+ d:DesignHeight="20" d:DesignWidth="20" d:DataContext="{d:DesignInstance Type=local:StorageTaskBarItem, IsDesignTimeCreatable=False}">
+ <Grid>
+ <touch:TouchIcon Width="20" Height="20" Icon="HddSolid">
+ <touch:TouchIcon.Style>
+ <Style TargetType="touch:TouchIcon" BasedOn="{StaticResource {x:Type touch:TouchIcon}}">
+ <Setter Property="Foreground" Value="{StaticResource TangoGrayBrush}"></Setter>
+ <Style.Triggers>
+ <DataTrigger Binding="{Binding StorageProvider.IsConnected}" Value="True">
+ <Setter Property="Foreground" Value="{StaticResource TangoSuccessBrush}"></Setter>
+ </DataTrigger>
+ </Style.Triggers>
+ </Style>
+ </touch:TouchIcon.Style>
+ </touch:TouchIcon>
+ </Grid>
+</UserControl>
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewContracts/IMainView.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewContracts/IMainView.cs
new file mode 100644
index 000000000..8c08f5a28
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewContracts/IMainView.cs
@@ -0,0 +1,15 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using Tango.PPC.Common;
+using Tango.SharedUI;
+
+namespace Tango.PPC.Storage.ViewContracts
+{
+ public interface IMainView : IPPCView
+ {
+ void NavigateBack();
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewModelLocator.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewModelLocator.cs
new file mode 100644
index 000000000..8634b8179
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewModelLocator.cs
@@ -0,0 +1,32 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using Tango.Core.DI;
+using Tango.PPC.Storage.ViewModels;
+
+namespace Tango.PPC.Storage
+{
+ public static class ViewModelLocator
+ {
+ /// <summary>
+ /// Initializes a new instance of the ViewModelLocator class.
+ /// </summary>
+ static ViewModelLocator()
+ {
+ TangoIOC.Default.Register<MainViewVM>();
+ }
+
+ /// <summary>
+ /// Gets the main view VM.
+ /// </summary>
+ public static MainViewVM MainViewVM
+ {
+ get
+ {
+ return TangoIOC.Default.GetInstance<MainViewVM>();
+ }
+ }
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/StorageViewVM.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewModels/MainViewVM.cs
index 5b5167393..cb48958dd 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/StorageViewVM.cs
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/ViewModels/MainViewVM.cs
@@ -6,11 +6,21 @@ using System.Threading.Tasks;
using Tango.Core.Commands;
using Tango.Explorer;
using Tango.PPC.Common;
+using Tango.PPC.Common.Navigation;
+using Tango.PPC.Storage.TaskBarItems;
+using Tango.PPC.Storage.ViewContracts;
-namespace Tango.PPC.UI.ViewModels
+namespace Tango.PPC.Storage.ViewModels
{
- public class StorageViewVM : PPCViewModel
+ /// <summary>
+ /// Represents the main view VM and entry point for <see cref="Storage.StorageModule"/>.
+ /// </summary>
+ /// <seealso cref="Tango.PPC.Common.PPCViewModel" />
+ public class MainViewVM : PPCViewModel<IMainView>, INavigationResultProvider<ExplorerFileItem, String>
{
+ private bool _allow_exit;
+ private ExplorerFileItem _selectedItem;
+
private String _currentPath;
public String CurrentPath
{
@@ -22,7 +32,7 @@ namespace Tango.PPC.UI.ViewModels
public RelayCommand<ExplorerFileItem> FileSelectedCommand { get; set; }
- public StorageViewVM()
+ public MainViewVM()
{
CloseCommand = new RelayCommand(Close);
FileSelectedCommand = new RelayCommand<ExplorerFileItem>(OnFileSelected);
@@ -37,6 +47,7 @@ namespace Tango.PPC.UI.ViewModels
{
base.OnApplicationReady();
+ NotificationProvider.PushTaskBarItem<StorageTaskBarItem>();
StorageProvider.StorageConnected += StorageProvider_StorageConnected;
StorageProvider.StorageDisconnected += StorageProvider_StorageDisconnected;
}
@@ -45,6 +56,9 @@ namespace Tango.PPC.UI.ViewModels
{
base.OnNavigatedTo();
+ _allow_exit = false;
+ _selectedItem = null;
+
if (StorageProvider.Drive != null)
{
CurrentPath = StorageProvider.Drive.RootDirectory.FullName;
@@ -53,7 +67,7 @@ namespace Tango.PPC.UI.ViewModels
private async void Close()
{
- await NavigationManager.NavigateTo(Common.Navigation.NavigationView.LayoutView);
+ await NavigationManager.NavigateBack();
}
/// <summary>
@@ -83,15 +97,39 @@ namespace Tango.PPC.UI.ViewModels
{
if (IsVisible)
{
- await NavigationManager.NavigateTo(Common.Navigation.NavigationView.LayoutView);
+ await NavigationManager.NavigateBack();
}
});
}
+ public override Task<bool> OnNavigateBackRequest()
+ {
+ if (CurrentPath == StorageProvider.Drive.RootDirectory.FullName || _allow_exit)
+ {
+ return Task.FromResult(true);
+ }
+ else
+ {
+ View.NavigateBack();
+ return Task.FromResult(false);
+ }
+ }
+
private async void OnFileSelected(ExplorerFileItem fileItem)
{
- await NavigationManager.NavigateTo(Common.Navigation.NavigationView.LayoutView);
+ _allow_exit = true;
+ await NavigationManager.NavigateBack();
await NotificationProvider.ShowInfo($"File Selected: {fileItem.Name}");
}
+
+ public ExplorerFileItem GetNavigationResult()
+ {
+ return _selectedItem;
+ }
+
+ public void OnNavigationObjectReceived(string extension)
+ {
+
+ }
}
}
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml
new file mode 100644
index 000000000..2fea4ce20
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml
@@ -0,0 +1,18 @@
+<UserControl x:Class="Tango.PPC.Storage.Views.MainView"
+ xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
+ xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
+ xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
+ xmlns:d="http://schemas.microsoft.com/expression/blend/2008"
+ xmlns:touch="clr-namespace:Tango.Touch.Controls;assembly=Tango.Touch"
+ xmlns:explorer="clr-namespace:Tango.Explorer;assembly=Tango.Explorer"
+ xmlns:vm="clr-namespace:Tango.PPC.Storage.ViewModels"
+ xmlns:global="clr-namespace:Tango.PPC.Storage"
+ xmlns:local="clr-namespace:Tango.PPC.Storage.Views"
+ mc:Ignorable="d"
+ d:DesignHeight="1280" d:DesignWidth="800" d:DataContext="{d:DesignInstance Type=vm:MainViewVM, IsDesignTimeCreatable=False}" DataContext="{x:Static global:ViewModelLocator.MainViewVM}" Background="{StaticResource TangoPrimaryBackgroundBrush}">
+ <Grid>
+ <Grid Margin="10">
+ <explorer:ExplorerControl x:Name="explorer" CurrentPath="{Binding CurrentPath,Mode=TwoWay}" FileSelectedCommand="{Binding FileSelectedCommand}" />
+ </Grid>
+ </Grid>
+</UserControl>
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml.cs
new file mode 100644
index 000000000..f77eaa401
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/Views/MainView.xaml.cs
@@ -0,0 +1,37 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using System.Windows;
+using System.Windows.Controls;
+using System.Windows.Data;
+using System.Windows.Documents;
+using System.Windows.Input;
+using System.Windows.Media;
+using System.Windows.Media.Imaging;
+using System.Windows.Navigation;
+using System.Windows.Shapes;
+using Tango.Core.DI;
+using Tango.PPC.Storage.ViewContracts;
+
+namespace Tango.PPC.Storage.Views
+{
+ /// <summary>
+ /// Interaction logic for MainView.xaml
+ /// </summary>
+ public partial class MainView : UserControl, IMainView
+ {
+ public MainView()
+ {
+ InitializeComponent();
+
+ TangoIOC.Default.Register<IMainView>(this);
+ }
+
+ public void NavigateBack()
+ {
+ explorer.NavigateBack();
+ }
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs
index 39cf2879f..dc693e305 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/INotificationProvider.cs
@@ -23,6 +23,11 @@ namespace Tango.PPC.Common.Notifications
ObservableCollection<NotificationItem> NotificationItems { get; }
/// <summary>
+ /// Gets the collection of taskbar items.
+ /// </summary>
+ ObservableCollection<TaskBarItem> TaskBarItems { get; }
+
+ /// <summary>
/// Gets the current application bar item.
/// </summary>
AppBarItem CurrentAppBarItem { get; }
@@ -167,5 +172,25 @@ namespace Tango.PPC.Common.Notifications
/// </summary>
/// <param name="appBarItem">The application bar item.</param>
void PopAppBarItem(AppBarItem appBarItem);
+
+ /// <summary>
+ /// Pushes the task bar item.
+ /// </summary>
+ /// <param name="taskBarItem">The task bar item.</param>
+ /// <returns></returns>
+ TaskBarItem PushTaskBarItem(TaskBarItem taskBarItem);
+
+ /// <summary>
+ /// Handles the Push Task Bar Item event.
+ /// </summary>
+ /// <typeparam name="T"></typeparam>
+ /// <returns></returns>
+ TaskBarItem PushTaskBarItem<T>() where T : TaskBarItem;
+
+ /// <summary>
+ /// Pops the task bar item.
+ /// </summary>
+ /// <param name="TaskBarItem">The task bar item.</param>
+ void PopTaskBarItem(TaskBarItem taskBarItem);
}
}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/TaskBarItem.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/TaskBarItem.cs
new file mode 100644
index 000000000..2d6a90317
--- /dev/null
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Notifications/TaskBarItem.cs
@@ -0,0 +1,13 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+
+namespace Tango.PPC.Common.Notifications
+{
+ public abstract class TaskBarItem : ItemBase
+ {
+
+ }
+}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/DefaultStorageProvider.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/DefaultStorageProvider.cs
index 5714f5dfb..46315e4b8 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/DefaultStorageProvider.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/DefaultStorageProvider.cs
@@ -7,6 +7,7 @@ using System.Threading;
using System.Threading.Tasks;
using Tango.Core;
using Tango.Core.DI;
+using Tango.Explorer;
using Tango.PPC.Common.Application;
using Tango.PPC.Common.Threading;
@@ -20,6 +21,7 @@ namespace Tango.PPC.Common.Storage
public class DefaultStorageProvider : ExtendedObject, IStorageProvider
{
private Thread _scanThread;
+ private Dictionary<String, Action<ExplorerFileItem>> _fileHandlers;
/// <summary>
/// Occurs when a new storage drive has been inserted.
@@ -56,8 +58,9 @@ namespace Tango.PPC.Common.Storage
/// </summary>
public DefaultStorageProvider(IPPCApplicationManager applicationManager)
{
+ _fileHandlers = new Dictionary<string, Action<ExplorerFileItem>>();
var drives = DriveInfo.GetDrives().Where(x => x.DriveType == DriveType.Removable).ToList();
-
+
if (drives.Count > 0)
{
IsConnected = true;
@@ -77,6 +80,49 @@ namespace Tango.PPC.Common.Storage
Initialize();
}
+ /// <summary>
+ /// Registers a method for handling a file selection.
+ /// </summary>
+ /// <param name="extension">The file extension.</param>
+ /// <param name="handler">The handler.</param>
+ /// <exception cref="System.InvalidOperationException">Cannot register multiple file handlers for the same extension.</exception>
+ public void RegisterFileHandler(string extension, Action<ExplorerFileItem> handler)
+ {
+ if (_fileHandlers.ContainsKey(extension))
+ {
+ throw new InvalidOperationException("Cannot register multiple file handlers for the same extension.");
+ }
+ _fileHandlers.Add(extension, handler);
+ }
+
+ /// <summary>
+ /// Unregisters the file handler.
+ /// </summary>
+ /// <param name="handler">The handler.</param>
+ public void UnregisterFileHandler(Action<ExplorerFileItem> handler)
+ {
+ var h = _fileHandlers.SingleOrDefault(x => x.Value == handler);
+
+ if (h.Key != null)
+ {
+ _fileHandlers.Remove(h.Key);
+ }
+ }
+
+ /// <summary>
+ /// Submits a file selection.
+ /// </summary>
+ /// <param name="fileItem">The file item.</param>
+ public void SubmitFileSelection(ExplorerFileItem fileItem)
+ {
+ String extension = Path.GetExtension(fileItem.Path);
+
+ if (_fileHandlers.ContainsKey(extension))
+ {
+ _fileHandlers[extension].Invoke(fileItem);
+ }
+ }
+
private void Initialize()
{
_scanThread = new Thread(ScanThreadMethod);
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/IStorageProvider.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/IStorageProvider.cs
index 164cdfe0a..902021002 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/IStorageProvider.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Storage/IStorageProvider.cs
@@ -4,6 +4,7 @@ using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
+using Tango.Explorer;
namespace Tango.PPC.Common.Storage
{
@@ -31,5 +32,24 @@ namespace Tango.PPC.Common.Storage
/// Gets the inserted storage drive information.
/// </summary>
DriveInfo Drive { get; }
+
+ /// <summary>
+ /// Registers a method for handling a file selection.
+ /// </summary>
+ /// <param name="extension">The file extension.</param>
+ /// <param name="handler">The handler.</param>
+ void RegisterFileHandler(String extension, Action<ExplorerFileItem> handler);
+
+ /// <summary>
+ /// Unregisters the file handler.
+ /// </summary>
+ /// <param name="handler">The handler.</param>
+ void UnregisterFileHandler(Action<ExplorerFileItem> handler);
+
+ /// <summary>
+ /// Submits a file selection.
+ /// </summary>
+ /// <param name="fileItem">The file item.</param>
+ void SubmitFileSelection(ExplorerFileItem fileItem);
}
}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Tango.PPC.Common.csproj b/Software/Visual_Studio/PPC/Tango.PPC.Common/Tango.PPC.Common.csproj
index eb90bfd77..d09acd30a 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.Common/Tango.PPC.Common.csproj
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Tango.PPC.Common.csproj
@@ -150,6 +150,7 @@
<Compile Include="Notifications\NotificationItems\MessageNotificationItemView.xaml.cs">
<DependentUpon>MessageNotificationItemView.xaml</DependentUpon>
</Compile>
+ <Compile Include="Notifications\TaskBarItem.cs" />
<Compile Include="PPCModuleAttribute.cs" />
<Compile Include="PPCModuleBase.cs" />
<Compile Include="Printing\IPrintingManager.cs" />
@@ -256,6 +257,10 @@
<Project>{63561e19-ff5a-414b-a5ef-e30711543e1d}</Project>
<Name>Tango.Emulations</Name>
</ProjectReference>
+ <ProjectReference Include="..\..\Tango.Explorer\Tango.Explorer.csproj">
+ <Project>{4399AF76-DB52-4CFB-8020-6F85BDB29FD5}</Project>
+ <Name>Tango.Explorer</Name>
+ </ProjectReference>
<ProjectReference Include="..\..\Tango.Integration\Tango.Integration.csproj">
<Project>{4206ac58-3b57-4699-8835-90bf6db01a61}</Project>
<Name>Tango.Integration</Name>
@@ -316,7 +321,7 @@
</Target>
<ProjectExtensions>
<VisualStudio>
- <UserProperties BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UseGlobalSettings="False" BuildVersion_StartDate="2000/1/1" />
+ <UserProperties BuildVersion_StartDate="2000/1/1" BuildVersion_UseGlobalSettings="False" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" />
</VisualStudio>
</ProjectExtensions>
</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Converters/NotificationItemConverter.cs b/Software/Visual_Studio/PPC/Tango.PPC.UI/Converters/ItemBaseConverter.cs
index 4e3291b97..cddfea894 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Converters/NotificationItemConverter.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/Converters/ItemBaseConverter.cs
@@ -11,11 +11,11 @@ using Tango.PPC.Common.Notifications;
namespace Tango.PPC.UI.Converters
{
- public class NotificationItemConverter : IValueConverter
+ public class ItemBaseConverter : IValueConverter
{
public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
{
- NotificationItem item = value as NotificationItem;
+ ItemBase item = value as ItemBase;
if (item != null)
{
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Notifications/DefaultNotificationProvider.cs b/Software/Visual_Studio/PPC/Tango.PPC.UI/Notifications/DefaultNotificationProvider.cs
index f03d9accd..f68d57805 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Notifications/DefaultNotificationProvider.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/Notifications/DefaultNotificationProvider.cs
@@ -36,11 +36,17 @@ namespace Tango.PPC.UI.Notifications
public ObservableCollection<NotificationItem> NotificationItems { get; private set; }
/// <summary>
+ /// Gets the collection of taskbar items.
+ /// </summary>
+ public ObservableCollection<TaskBarItem> TaskBarItems { get; private set; }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="DefaultNotificationProvider"/> class.
/// </summary>
public DefaultNotificationProvider()
{
NotificationItems = new ObservableCollection<NotificationItem>();
+ TaskBarItems = new ObservableCollection<TaskBarItem>();
_pendingMessageBoxes = new ConcurrentQueue<PendingNotification<MessageBoxVM, bool>>();
_pendingDialogs = new ConcurrentQueue<PendingNotification<DialogAndView, DialogViewVM>>();
@@ -441,5 +447,35 @@ namespace Tango.PPC.UI.Notifications
LogManager.Log($"Popping out AppBarItem '{appBarItem.GetType().Name}'.");
CurrentAppBarItem = null;
}
+
+ /// <summary>
+ /// Pushes the task bar item.
+ /// </summary>
+ /// <param name="taskBarItem">The task bar item.</param>
+ /// <returns></returns>
+ public TaskBarItem PushTaskBarItem(TaskBarItem taskBarItem)
+ {
+ TaskBarItems.Add(taskBarItem);
+ return taskBarItem;
+ }
+
+ /// <summary>
+ /// Handles the Push Task Bar Item event.
+ /// </summary>
+ /// <typeparam name="T"></typeparam>
+ /// <returns></returns>
+ public TaskBarItem PushTaskBarItem<T>() where T : TaskBarItem
+ {
+ return PushTaskBarItem(Activator.CreateInstance<T>());
+ }
+
+ /// <summary>
+ /// Pops the task bar item.
+ /// </summary>
+ /// <param name="taskBarItem"></param>
+ public void PopTaskBarItem(TaskBarItem taskBarItem)
+ {
+ TaskBarItems.Remove(taskBarItem);
+ }
}
}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj b/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj
index 466ff0587..f615f25e0 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/Tango.PPC.UI.csproj
@@ -118,7 +118,7 @@
</Compile>
<Compile Include="Connectivity\WiFiAuthenticationViewVM.cs" />
<Compile Include="Converters\AppBarItemConverter.cs" />
- <Compile Include="Converters\NotificationItemConverter.cs" />
+ <Compile Include="Converters\ItemBaseConverter.cs" />
<Compile Include="Modules\DefaultStudioModuleLoader.cs" />
<Compile Include="Navigation\DefaultNavigationManager.cs" />
<Compile Include="Notifications\DefaultNotificationProvider.cs" />
@@ -135,7 +135,6 @@
<Compile Include="ViewModels\MachineSetupViewVM.cs" />
<Compile Include="ViewModels\MainViewVM.cs" />
<Compile Include="ViewModels\MachineUpdateViewVM.cs" />
- <Compile Include="ViewModels\StorageViewVM.cs" />
<Compile Include="ViewsContracts\ILayoutView.cs" />
<Compile Include="ViewsContracts\IMachineSetupView.cs" />
<Compile Include="ViewsContracts\IMachineUpdateView.cs" />
@@ -160,9 +159,6 @@
<Compile Include="Views\MachineUpdateView.xaml.cs">
<DependentUpon>MachineUpdateView.xaml</DependentUpon>
</Compile>
- <Compile Include="Views\StorageView.xaml.cs">
- <DependentUpon>StorageView.xaml</DependentUpon>
- </Compile>
<Page Include="Connectivity\WiFiAuthenticationView.xaml">
<SubType>Designer</SubType>
<Generator>MSBuild:Compile</Generator>
@@ -219,10 +215,6 @@
<SubType>Designer</SubType>
<Generator>MSBuild:Compile</Generator>
</Page>
- <Page Include="Views\StorageView.xaml">
- <SubType>Designer</SubType>
- <Generator>MSBuild:Compile</Generator>
- </Page>
</ItemGroup>
<ItemGroup>
<Compile Include="Properties\AssemblyInfo.cs">
@@ -327,6 +319,10 @@
<Project>{91b70e9b-66a7-4873-ae10-400e71cf404f}</Project>
<Name>Tango.PPC.MachineSettings</Name>
</ProjectReference>
+ <ProjectReference Include="..\Modules\Tango.PPC.Storage\Tango.PPC.Storage.csproj">
+ <Project>{04febb02-f782-4b96-b47d-f6902afa43be}</Project>
+ <Name>Tango.PPC.Storage</Name>
+ </ProjectReference>
<ProjectReference Include="..\Tango.PPC.Common\Tango.PPC.Common.csproj">
<Project>{0be74eee-22cb-4dba-b896-793b9e1a3ac0}</Project>
<Name>Tango.PPC.Common</Name>
@@ -445,7 +441,7 @@ copy /Y "$(SolutionDir)Referenced Assemblies\vcruntime140d.dll" "$(TargetDir)"</
</PropertyGroup>
<ProjectExtensions>
<VisualStudio>
- <UserProperties BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UseGlobalSettings="False" BuildVersion_StartDate="2000/1/1" />
+ <UserProperties BuildVersion_StartDate="2000/1/1" BuildVersion_UseGlobalSettings="False" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" />
</VisualStudio>
</ProjectExtensions>
</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs b/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs
index 47f4409f5..703a2f6ae 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModelLocator.cs
@@ -88,7 +88,6 @@ namespace Tango.PPC.UI
TangoIOC.Default.Register<ExternalBridgeViewVM>();
TangoIOC.Default.Register<MachineSetupViewVM>();
TangoIOC.Default.Register<MachineUpdateViewVM>();
- TangoIOC.Default.Register<StorageViewVM>();
TangoIOC.Default.GetInstance<IPPCApplicationManager>().ContentRendered += (_, __) =>
@@ -162,13 +161,5 @@ namespace Tango.PPC.UI
return TangoIOC.Default.GetInstance<MachineUpdateViewVM>();
}
}
-
- public static StorageViewVM StorageViewVM
- {
- get
- {
- return TangoIOC.Default.GetInstance<StorageViewVM>();
- }
- }
}
} \ No newline at end of file
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/LayoutView.xaml b/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/LayoutView.xaml
index 44a66d7f0..076cd09e4 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/LayoutView.xaml
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/LayoutView.xaml
@@ -18,7 +18,7 @@
d:DesignHeight="1280" d:DesignWidth="800" d:DataContext="{d:DesignInstance Type=vm:LayoutViewVM, IsDesignTimeCreatable=False}" DataContext="{x:Static global:ViewModelLocator.LayoutViewVM}">
<UserControl.Resources>
- <localConverters:NotificationItemConverter x:Key="NotificationItemConverter" />
+ <localConverters:ItemBaseConverter x:Key="NotificationItemConverter" />
<localConverters:AppBarItemConverter x:Key="AppBarItemConverter" />
</UserControl.Resources>
@@ -63,15 +63,6 @@
<StackPanel Margin="0 5 0 0">
- <Border BorderBrush="{StaticResource TangoDividerBrush}" BorderThickness="0 1 0 0" Visibility="{Binding StorageProvider.IsConnected,Converter={StaticResource BooleanToVisibilityConverter}}">
- <touch:TouchButton Style="{StaticResource TangoFlatButton}" Padding="30" Foreground="{StaticResource TangoDarkForegroundBrush}" Command="{Binding StorageCommand}" FontSize="{StaticResource TangoHeaderFontSize}">
- <StackPanel Orientation="Horizontal" HorizontalAlignment="Left">
- <Image Source="/Images/flash-drive.png" VerticalAlignment="Center" Width="48" Height="48"></Image>
- <TextBlock VerticalAlignment="Center" Margin="20 0 0 0">Storage</TextBlock>
- </StackPanel>
- </touch:TouchButton>
- </Border>
-
<Border BorderBrush="{StaticResource TangoDividerBrush}" BorderThickness="0 1 0 0">
<touch:TouchButton Style="{StaticResource TangoFlatButton}" Padding="30" Foreground="{StaticResource TangoDarkForegroundBrush}" Command="{Binding UpdateCommand}" FontSize="{StaticResource TangoHeaderFontSize}">
<StackPanel Orientation="Horizontal" HorizontalAlignment="Left">
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/MainView.xaml b/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/MainView.xaml
index 690022e64..7eca6dba6 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/MainView.xaml
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/MainView.xaml
@@ -16,7 +16,7 @@
d:DesignHeight="1280" d:DesignWidth="800" d:DataContext="{d:DesignInstance Type=vm:MainViewVM, IsDesignTimeCreatable=False}" DataContext="{x:Static global:ViewModelLocator.MainViewVM}">
<UserControl.Resources>
- <localConverters:NotificationItemConverter x:Key="NotificationItemConverter" />
+ <localConverters:ItemBaseConverter x:Key="ItemBaseConverter" />
</UserControl.Resources>
<Grid>
@@ -33,7 +33,7 @@
<touch:TouchButton Style="{StaticResource TangoFlatButton}" Padding="0" Command="{Binding PressedCommand}" components:TransformationHelper.TransformWhenPressed="False">
<DockPanel>
<touch:TouchIconButton DockPanel.Dock="Right" Background="Transparent" Padding="20" Style="{StaticResource TangoRoundTouchIconButton}" Command="{Binding CloseCommand}" CommandParameter="{Binding}" HorizontalAlignment="Right" MaxHeight="60" Width="{Binding RelativeSource={RelativeSource Self},Path=ActualHeight}" Icon="Close" Foreground="White" />
- <ContentControl Content="{Binding Converter={StaticResource NotificationItemConverter}}"/>
+ <ContentControl Content="{Binding Converter={StaticResource ItemBaseConverter}}"/>
</DockPanel>
</touch:TouchButton>
</DataTemplate>
@@ -57,18 +57,19 @@
</Style>
</touch:TouchIcon.Style>
</touch:TouchIcon>
- <touch:TouchIcon Width="20" Height="20" VerticalAlignment="Center" Margin="10 0 0 0" Icon="HddSolid">
- <touch:TouchIcon.Style>
- <Style TargetType="touch:TouchIcon" BasedOn="{StaticResource {x:Type touch:TouchIcon}}">
- <Setter Property="Foreground" Value="{StaticResource TangoGrayBrush}"></Setter>
- <Style.Triggers>
- <DataTrigger Binding="{Binding StorageProvider.IsConnected}" Value="True">
- <Setter Property="Foreground" Value="{StaticResource TangoSuccessBrush}"></Setter>
- </DataTrigger>
- </Style.Triggers>
- </Style>
- </touch:TouchIcon.Style>
- </touch:TouchIcon>
+
+ <ItemsControl ItemsSource="{Binding NotificationProvider.TaskBarItems}">
+ <ItemsControl.ItemsPanel>
+ <ItemsPanelTemplate>
+ <StackPanel Orientation="Horizontal" />
+ </ItemsPanelTemplate>
+ </ItemsControl.ItemsPanel>
+ <ItemsControl.ItemTemplate>
+ <DataTemplate>
+ <ContentControl Width="20" Height="20" VerticalAlignment="Center" Margin="10 0 0 0" Content="{Binding Converter={StaticResource ItemBaseConverter}}"/>
+ </DataTemplate>
+ </ItemsControl.ItemTemplate>
+ </ItemsControl>
<Grid></Grid>
</DockPanel>
</Border>
@@ -81,7 +82,6 @@
<local:ExternalBridgeView></local:ExternalBridgeView>
<local:MachineSetupView></local:MachineSetupView>
<local:MachineUpdateView></local:MachineUpdateView>
- <local:StorageView></local:StorageView>
</controls:NavigationControl>
</touch:TouchPanel>
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/StorageView.xaml b/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/StorageView.xaml
deleted file mode 100644
index aa7bdcf7d..000000000
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/StorageView.xaml
+++ /dev/null
@@ -1,33 +0,0 @@
-<UserControl x:Class="Tango.PPC.UI.Views.StorageView"
- xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
- xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
- xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
- xmlns:d="http://schemas.microsoft.com/expression/blend/2008"
- xmlns:global="clr-namespace:Tango.PPC.UI"
- xmlns:touch="clr-namespace:Tango.Touch.Controls;assembly=Tango.Touch"
- xmlns:vm="clr-namespace:Tango.PPC.UI.ViewModels"
- xmlns:local="clr-namespace:Tango.PPC.UI.Views"
- xmlns:explorer="clr-namespace:Tango.Explorer;assembly=Tango.Explorer"
- mc:Ignorable="d"
- d:DesignHeight="1280" d:DesignWidth="800" d:DataContext="{d:DesignInstance Type=vm:StorageViewVM, IsDesignTimeCreatable=False}" DataContext="{x:Static global:ViewModelLocator.StorageViewVM}" Background="{StaticResource TangoPrimaryBackgroundBrush}">
- <DockPanel>
-
- <Border DockPanel.Dock="Top" Background="{StaticResource TangoMidBackgroundBrush}" BorderBrush="{StaticResource TangoDividerBrush}" BorderThickness="0 0 0 1">
- <Border.Effect>
- <DropShadowEffect BlurRadius="15" Color="{StaticResource TangoDropShadowColor}" />
- </Border.Effect>
- <DockPanel Margin="10" Height="80" LastChildFill="False">
- <touch:TouchIconButton Style="{StaticResource TangoRoundTouchIconButton}" Padding="20" Margin="5" Icon="ArrowLeftBold" Command="{Binding ElementName=explorer,Path=BackCommand}">
-
- </touch:TouchIconButton>
-
- <touch:TouchIconButton Icon="Close" Style="{StaticResource TangoRoundTouchIconButton}" Padding="20" Margin="5" DockPanel.Dock="Right" Command="{Binding CloseCommand}"></touch:TouchIconButton>
- </DockPanel>
- </Border>
-
- <Grid Margin="10">
- <explorer:ExplorerControl x:Name="explorer" CurrentPath="{Binding CurrentPath,Mode=TwoWay}" FileSelectedCommand="{Binding FileSelectedCommand}" />
- </Grid>
-
- </DockPanel>
-</UserControl>
diff --git a/Software/Visual_Studio/Tango.BL/EntitiesExtensions/LiquidTypesRml.cs b/Software/Visual_Studio/Tango.BL/EntitiesExtensions/LiquidTypesRml.cs
index c4ccb4ab6..ef00cb5a8 100644
--- a/Software/Visual_Studio/Tango.BL/EntitiesExtensions/LiquidTypesRml.cs
+++ b/Software/Visual_Studio/Tango.BL/EntitiesExtensions/LiquidTypesRml.cs
@@ -11,6 +11,10 @@ namespace Tango.BL.Entities
{
public CalibrationData GetCalibrationData()
{
+ if (DefaultCatData == null)
+ {
+ throw LogManager.Log(new NullReferenceException("The default RML calibration data is null."));
+ }
return CalibrationData.Parser.ParseFrom(DefaultCatData);
}
diff --git a/Software/Visual_Studio/Tango.Explorer/ExplorerControl.cs b/Software/Visual_Studio/Tango.Explorer/ExplorerControl.cs
index 0c713a7db..197380475 100644
--- a/Software/Visual_Studio/Tango.Explorer/ExplorerControl.cs
+++ b/Software/Visual_Studio/Tango.Explorer/ExplorerControl.cs
@@ -114,7 +114,7 @@ namespace Tango.Explorer
}
}
- private void NavigateBack()
+ public void NavigateBack()
{
if (CurrentFolder != null)
{
diff --git a/Software/Visual_Studio/Tango.sln b/Software/Visual_Studio/Tango.sln
index 490ea56b3..fe2f0a90c 100644
--- a/Software/Visual_Studio/Tango.sln
+++ b/Software/Visual_Studio/Tango.sln
@@ -236,6 +236,8 @@ Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Tango.Explorer", "Tango.Exp
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Tango.JobRunsGenerator", "Utilities\Tango.JobRunsGenerator\Tango.JobRunsGenerator.csproj", "{4EDCF067-E377-42CB-A18C-8368CF484577}"
EndProject
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Tango.PPC.Storage", "PPC\Modules\Tango.PPC.Storage\Tango.PPC.Storage.csproj", "{04FEBB02-F782-4B96-B47D-F6902AFA43BE}"
+EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
AppVeyor|Any CPU = AppVeyor|Any CPU
@@ -4199,6 +4201,46 @@ Global
{4EDCF067-E377-42CB-A18C-8368CF484577}.Release|x64.Build.0 = Release|Any CPU
{4EDCF067-E377-42CB-A18C-8368CF484577}.Release|x86.ActiveCfg = Release|Any CPU
{4EDCF067-E377-42CB-A18C-8368CF484577}.Release|x86.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|Any CPU.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|Any CPU.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|ARM.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|ARM.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|ARM64.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|ARM64.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|x64.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|x64.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|x86.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.AppVeyor|x86.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|ARM.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|ARM.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|ARM64.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|ARM64.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|x64.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|x64.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|x86.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Debug|x86.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|Any CPU.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|Any CPU.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|ARM.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|ARM.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|ARM64.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|ARM64.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|x64.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|x64.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|x86.ActiveCfg = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.DefaultBuild|x86.Build.0 = Debug|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|Any CPU.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|ARM.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|ARM.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|ARM64.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|ARM64.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|x64.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|x64.Build.0 = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|x86.ActiveCfg = Release|Any CPU
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE}.Release|x86.Build.0 = Release|Any CPU
EndGlobalSection
GlobalSection(SolutionProperties) = preSolution
HideSolutionNode = FALSE
@@ -4271,14 +4313,15 @@ Global
{72E591D6-8F83-4D8C-8F67-9C325E623234} = {EC62BC9C-F2FE-4333-B7E4-110E38D43958}
{8A65AD6A-A9B4-48C0-9301-4B7434B712F8} = {B2AF4F3F-2828-47C3-8F3E-A0EA0BD66FF8}
{4EDCF067-E377-42CB-A18C-8368CF484577} = {5F6BBAA8-EAD0-4B18-97E5-55B4F56DD760}
+ {04FEBB02-F782-4B96-B47D-F6902AFA43BE} = {0048447D-1D94-4E60-9DAD-7349C777CB4E}
EndGlobalSection
GlobalSection(ExtensibilityGlobals) = postSolution
- SolutionGuid = {7986F7F4-A86A-4994-B1B6-0988D7F057B6}
- BuildVersion_BuildVersioningStyle = None.None.Increment.DeltaBaseYearDayOfYear
- BuildVersion_UpdateAssemblyVersion = True
- BuildVersion_UpdateFileVersion = False
- BuildVersion_StartDate = 2000/1/1
- BuildVersion_AssemblyInfoFilename = Properties\AssemblyInfo.cs
BuildVersion_UseGlobalSettings = False
+ BuildVersion_AssemblyInfoFilename = Properties\AssemblyInfo.cs
+ BuildVersion_StartDate = 2000/1/1
+ BuildVersion_UpdateFileVersion = False
+ BuildVersion_UpdateAssemblyVersion = True
+ BuildVersion_BuildVersioningStyle = None.None.Increment.DeltaBaseYearDayOfYear
+ SolutionGuid = {7986F7F4-A86A-4994-B1B6-0988D7F057B6}
EndGlobalSection
EndGlobal
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/StorageView.xaml.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItemView.xaml.cs
index d558d08bf..f66cf4465 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/Views/StorageView.xaml.cs
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Storage/TaskBarItems/StorageTaskBarItemView.xaml.cs
@@ -13,14 +13,14 @@ using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
-namespace Tango.PPC.UI.Views
+namespace Tango.PPC.Storage.TaskBarItems
{
/// <summary>
/// Interaction logic for StorageView.xaml
/// </summary>
- public partial class StorageView : UserControl
+ public partial class StorageTaskBarItemView : UserControl
{
- public StorageView()
+ public StorageTaskBarItemView()
{
InitializeComponent();
}
@@ -13,14 +13,14 @@ using System.Windows.Media.Imaging;
{
/// <summary>
- /// Interaction logic for StorageView.xaml
+ /// Interaction logic for StorageTaskBarItem.xaml
/// </summary>